Index: src/objects.h |
diff --git a/src/objects.h b/src/objects.h |
index 320531cfd588aa61ebd344477be4202cd3cd95fb..e109fa68d72db141fbd62564aef50d13072f8e19 100644 |
--- a/src/objects.h |
+++ b/src/objects.h |
@@ -10584,12 +10584,13 @@ class JSArray: public JSObject { |
static const int kLengthOffset = JSObject::kHeaderSize; |
static const int kSize = kLengthOffset + kPointerSize; |
// 600 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which |
// we do not want to include in objects.h |
// Note that Page::kMaxRegularHeapObjectSize has to be in sync with |
// kInitialMaxFastElementArray which is checked in a DCHECK in heap.cc. |
static const int kInitialMaxFastElementArray = |
- (600 * KB - FixedArray::kHeaderSize - kSize - AllocationMemento::kSize) / |
+ (512 * KB - 384 - FixedArray::kHeaderSize - kSize - |
+ AllocationMemento::kSize) / |
kPointerSize; |
private: |
@@ -10584,12 +10584,13 @@ class JSArray: public JSObject { |
static const int kLengthOffset = JSObject::kHeaderSize; |
static const int kSize = kLengthOffset + kPointerSize; |
- // 600 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which |
- // we do not want to include in objects.h |
+ // (512 * KB - 384) is the Page::kMaxRegularHeapObjectSize defined in spaces.h |
+ // which we do not want to include in objects.h |
// Note that Page::kMaxRegularHeapObjectSize has to be in sync with |
// kInitialMaxFastElementArray which is checked in a DCHECK in heap.cc. |